import requests

class Summoner:
    def __init__(self, host):
        self.host = host.platformRouting
        self.Token = host.Token

    def byEncryptedAccountId(self, accountId):
        def makeRequest():
            url = f"https://{self.host}/lol/summoner/v4/summoners/by-account/{accountId}"
            response = requests.get(url, headers={"X-Riot-Token":self.Token})
            self.byEncryptedAccountIdJson = response.json()

        makeRequest()
        return self.byEncryptedAccountIdJson

    def bySummonerName(self, summonerName):
        def makeRequest():
            url = f"https://{self.host}/lol/summoner/v4/summoners/by-name/{summonerName}"
            response = requests.get(url, headers={"X-Riot-Token": self.Token})
            self.byNameJson = response.json()

        makeRequest()
        return self.byNameJson

    def byEncryptedPUUID(self, puuid):
        def makeRequest():
            url = f"https://{self.host}/lol/summoner/v4/summoners/by-puuid/{puuid}"
            response = requests.get(url, headers={"X-Riot-Token":self.Token})
            self.byEncryptedPUUIDJson = response.json()

        makeRequest()
        return self.byEncryptedPUUIDJson

    def byEncryptedSummonerId(self,encryptedSummonerId):
        def makeRequest():
            url = f"https://{self.host}/lol/summoner/v4/summoners/{encryptedSummonerId}"
            response = requests.get(url, headers={"X-Riot-Token":self.Token})
            self.byEncryptedSummonerId = response.json()

        makeRequest()
        return self.byEncryptedSummonerId



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="LeagueLibrary",
    version="2021.08.15",
    author="Gabriel Veras",
    author_email="developergabrielveras@gmail.com",
    description="LeagueLibrary is a library for Python3 based on the origial Riot Games API.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Groot-cmd/LeagueLibrary",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"":"LeagueLibrary"},
    packages=setuptools.find_packages(where="LeagueLibrary"),
    python_requires=">=3.9",
)



import requests

platformID_List = ["br1","eun1","euw1","jp1","kr","la1","la2","na1","oc1","tr1","ru"]
regions_List = ["americas","asia","europe"]
url_Base = "api.riotgames.com"

class Host:
    def __init__(self, platformID, regions, token):
        self.Token = token
        self.platformID = platformID
        self.region = regions

        #PlatformID Verification
        if self.platformID.isupper():
            self.platformID = self.platformID.lower()

        if self.platformID in platformID_List:
            self.platformRouting = f"{self.platformID}.{url_Base}"

        else:
            raise Exception(f"[platformID]: '{self.platformID}' It's not on the list")

        #Regions Verification
        if self.region.isupper():
            self.region = self.region.lower()

        if self.region in regions_List:
            self.regionRouting = f"{self.region}.{url_Base}"

        else:
            raise Exception(f"[region]: '{self.region}' It's not on the list")

    def Status(self):
        def makeRequest():
            url = f"https://{self.platformRouting}/lol/status/v3/shard-data"
            response = requests.get(url, headers={"X-Riot-Token": self.Token})
            return response.json()
        statusResponse = makeRequest()

        for here in statusResponse['services']:
            if here['status'] == "online":
                print(f"[{here['name']}]: {here['status']}")
            else:
                print(f"[{here['name']}]: {here['status']}")
